==> react-atom-tag-2.44.0.tgz: package/lib/Actionable/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import { LINK_TYPES } from '../constants.js';
import ActionableTagContainer from './Container.js';
import { getClassNames, getLinkTypesString, LEFT_ICON_PLACEMENT, onHandler, RIGHT_ICON_PLACEMENT } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var ActionableTag = function ActionableTag(_ref) {
  var icon = _ref.icon,
      href = _ref.href,
      iconPlacement = _ref.iconPlacement,
      label = _ref.label,
      onClick = _ref.onClick,
      target = _ref.target,
      rel = _ref.rel,
      linkFactory = _ref.linkFactory,
      className = _ref.className,
      readOnly = _ref.readOnly,
      disabled = _ref.disabled,
      title = _ref.title,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? null : _ref$value;
  return /*#__PURE__*/_jsxs(ActionableTagContainer, {
    className: getClassNames({
      className: className
    }),
    Link: linkFactory,
    onClick: onHandler({
      disabled: disabled,
      readOnly: readOnly
    }, onClick, {
      value: value,
      label: label
    }),
    href: href,
    target: target,
    rel: rel,
    readOnly: readOnly,
    disabled: disabled,
    children: [icon && iconPlacement === LEFT_ICON_PLACEMENT && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-icon",
      children: icon
    }), /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-label",
      title: title || label,
      children: label
    }), icon && iconPlacement === RIGHT_ICON_PLACEMENT && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-secondary-icon",
      children: icon
    })]
  });
};

ActionableTag.defaultProps = {
  // eslint-disable-next-line react/prop-types
  linkFactory: function linkFactory(_temp) {
    var _ref2 = _temp === void 0 ? {} : _temp,
        href = _ref2.href,
        target = _ref2.target,
        rel = _ref2.rel,
        className = _ref2.className,
        role = _ref2.role,
        children = _ref2.children;

    var optionalProps = _extends({}, rel && {
      rel: getLinkTypesString(rel)
    });

    return /*#__PURE__*/_jsx("a", _extends({
      href: href,
      target: target,
      className: className,
      role: role
    }, optionalProps, {
      children: children
    }));
  }
};
export default ActionableTag;

==> react-atom-tag-2.47.0.tgz: package/lib/Actionable/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import { LINK_TYPES } from '../constants.js';
import ActionableTagContainer from './Container.js';
import { getClassNames, getLinkTypesString, LEFT_ICON_PLACEMENT, onHandler, RIGHT_ICON_PLACEMENT } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var ActionableTag = function ActionableTag(_ref) {
  var icon = _ref.icon,
    href = _ref.href,
    iconPlacement = _ref.iconPlacement,
    label = _ref.label,
    onClick = _ref.onClick,
    target = _ref.target,
    rel = _ref.rel,
    linkFactory = _ref.linkFactory,
    className = _ref.className,
    readOnly = _ref.readOnly,
    disabled = _ref.disabled,
    title = _ref.title,
    _ref$value = _ref.value,
    value = _ref$value === void 0 ? null : _ref$value;
  return /*#__PURE__*/_jsxs(ActionableTagContainer, {
    className: getClassNames({
      className: className
    }),
    Link: linkFactory,
    onClick: onHandler({
      disabled: disabled,
      readOnly: readOnly
    }, onClick, {
      value: value,
      label: label
    }),
    href: href,
    target: target,
    rel: rel,
    readOnly: readOnly,
    disabled: disabled,
    children: [icon && iconPlacement === LEFT_ICON_PLACEMENT && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-icon",
      children: icon
    }), label ? /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-label",
      title: title || label,
      children: label
    }) : null, icon && iconPlacement === RIGHT_ICON_PLACEMENT && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-secondary-icon",
      children: icon
    })]
  });
};
ActionableTag.defaultProps = {
  // eslint-disable-next-line react/prop-types
  linkFactory: function linkFactory(_temp) {
    var _ref2 = _temp === void 0 ? {} : _temp,
      href = _ref2.href,
      target = _ref2.target,
      rel = _ref2.rel,
      className = _ref2.className,
      role = _ref2.role,
      children = _ref2.children;
    var optionalProps = _extends({}, rel && {
      rel: getLinkTypesString(rel)
    });
    return /*#__PURE__*/_jsx("a", _extends({
      href: href,
      target: target,
      className: className,
      role: role
    }, optionalProps, {
      children: children
    }));
  }
};
export default ActionableTag;
